@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use CPAN::Meta;
 use Carp;
@@ -349,7 +349,7 @@ sub _build_dist {
 sub _dist_from_local_files {
     my ($meta) = grep {-r} qw( MYMETA.json MYMETA.yml META.json META.yml );
     if ($meta) {
-        my $cm = CPAN::Meta->new($meta);
+        my $cm = CPAN::Meta->load_file($meta);
         return $cm->name;
     }
     elsif ( -r 'dist.ini' ) {
@@ -776,7 +776,7 @@ RTx::ToGitHub - Convert rt.cpan.org tickets to GitHub issues
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -907,12 +907,22 @@ button at L<http://www.urth.org/~autarch/fs-donation.html>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Dan Stewart
+=for stopwords Dan Stewart Michiel Beijen
+
+=over 4
+
+=item *
 
 Dan Stewart <danielandrewstewart@gmail.com>
 
+=item *
+
+Michiel Beijen <michiel.beijen@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by David Golden and Dave Rolsky.
